# L3C

L3C provides variant environments facilitating In-Context Learning, featured in the following assets:
- Minimal knowledge transferrable among huge amounts of tasks
- Lifelong In-Context Learning
- Generative and Interactive

# Environments Updating

- [MazeWorlds](l3c/mazeworld): 2D/3D maze generators for task generalization

- [MetaLanguage](l3c/metalang): Pseudo-language generated from randomized hyper-parameters

- [Bandits](l3c/bandits): Bandits task generalization

- [L3C_Baselines](https://github.com/FutureAGI/L3C_Baselines): An implementation of the baseline solutions to the above tasks

# Installation

```bash
pip install l3c
```
